@@ -1,6 +1,6 @@
 # Copyright (C) 2022 Pavocracy <pavocracy@pm.me>
-# Signed using RSA key 9A5D2D5AA10873B9ABCD92F1D959AEE8875DEEE6
 # This file is released as part of leetscraper under GPL-2.0 License.
+# Find this project at https://github.com/Pavocracy/leetscraper
 
 """
   __             __
@@ -16,7 +16,7 @@ website, will set some attributes that will allow coding challenges to be reques
 filtered down to the problem description, and written to a markdown file.
 
 This scraper currently works for:
-leetcode.com, projecteuler.net, codechef.com, hackerrank.com, codewars.com
+codechef.com, codewars.com, hackerrank.com, leetcode.com, projecteuler.net.
 
 It uses chrome or firefox with Selenium to scrape problems. If chrome or firefox are not
 installed on your machine this scraper will raise an Exception and exit without scraping.
@@ -28,10 +28,11 @@ See related docstrings for help.
 
 from os import getcwd
 
-from .driver import create_webdriver, webdriver_quit
-from .logger import get_logger
+from .driver import check_installed_webdrivers, create_webdriver
+from .logger import log_message
 from .scraper import check_problems, needed_problems, scrape_problems
 from .system import check_path, check_platform, check_supported_browsers
+from .version import check_version
 from .website import set_website
 
 
@@ -40,7 +41,7 @@ class Leetscraper:
 
     website_name: name of a supported website to scrape ("leetcode.com" set if ignored)
     scrape_path: "path/to/save/problems" (Current working directory set if ignored)
-    scrape_limit: Integer of how many problems to scrape at a time (no limit set if ignored)
+    scrape_limit: integer of how many problems to scrape at a time (no limit set if ignored)
     auto_scrape: "True", "False" (True set if ignored)
 
     This means calling this class with no arguments will result in all leetcode problems
@@ -57,24 +58,33 @@ class Leetscraper:
             message = (
                 f"scrape_limit error!: Cannot scrape {self.scrape_limit} problems!"
             )
-            logger = get_logger()
-            logger.exception(message)
-            raise Exception(message)
+            log_message("exception", message)
+            raise ValueError(message)
         if not self.auto_scrape:
             return
         self.driver, self.get_problems = self.setup_scraper()
         self.scraped = self.start_scraping()
-        webdriver_quit(self.driver, self.website.website_name)
 
     def setup_scraper(self) -> tuple:
         """Calling this method is required to setup the arguments needed to scrape."""
         user_platform = check_platform()
         browsers = check_supported_browsers(user_platform)
         scraped_problems = check_problems(self.website, self.scrape_path)
+        version = check_version()
         get_problems = needed_problems(
-            self.website, scraped_problems, self.scrape_limit
+            self.website,
+            scraped_problems,
+            self.scrape_limit,
+            browsers,
+            version,
+        )
+        installed_webdrivers = check_installed_webdrivers()
+        driver = create_webdriver(
+            browsers,
+            self.website,
+            installed_webdrivers,
+            version,
         )
-        driver = create_webdriver(browsers, self.website.website_name)
         return driver, get_problems
 
     def start_scraping(self) -> int:
